@@ -119,11 +119,6 @@ def run():
         else:
             from strange_case.strange_case_config import CONFIG
 
-        args = parser.parse_args()
-        for conf in conf_overrides:
-            if getattr(args, conf) is not None:
-                CONFIG[conf] = getattr(args, conf)
-
         # normalize paths
         for conf in ['project_path', 'site_path', 'deploy_path']:
             if CONFIG[conf][0] == '~':
@@ -140,17 +135,21 @@ def run():
             if yaml_config:
                 CONFIG.update(yaml_config)
 
+        args = parser.parse_args()
+        for conf in conf_overrides:
+            if getattr(args, conf) is not None:
+                CONFIG[conf] = getattr(args, conf)
+
         assign = None
         for confs in args.configs:
             if assign:
                 CONFIG[assign] = confs
                 assign = None
-            else:
+            elif ':' in confs:
                 key, val = confs.split(':', 1)
-                if len(val) == 0:
-                    assign = key
-                else:
-                    CONFIG[key] = val
+                CONFIG[key] = val
+            else:
+                assign = confs
 
         if CONFIG['config_hook']:
             CONFIG['config_hook'](CONFIG)
@@ -181,7 +180,7 @@ def run():
         del CONFIG['extensions']
 
     if not Registry.get('jinja_environment', None):
-        jinja_environment = StrangeCaseEnvironment(extensions=extensions)
+        jinja_environment = StrangeCaseEnvironment(extensions=extensions, project_path=CONFIG['project_path'])
         Registry.set('jinja_environment', jinja_environment)
     else:
         jinja_environment = Registry.get('jinja_environment')
@@ -269,7 +268,7 @@ def run():
             while True:
                 time.sleep(1)
         except KeyboardInterrupt:
-            sys.stderr("Stopping\n")
+            sys.stderr.write("Stopping\n")
             observer.stop()
         observer.join()
     else:
